#!/usr/bin/python

import glob
import os
import re
import shutil
import sys
import tarfile
import urllib
from sgmllib import SGMLParser

class URLLister(SGMLParser):
	def reset(self):
		SGMLParser.reset(self)
		self.urls = []
	def start_a(self, attrs):
		href = [v for k, v in attrs if k=='href']
		if href:
			self.urls.extend(href)

def dlProgress(count, blockSize, totalSize):
	percent = int(count*blockSize*100/totalSize)
	sys.stdout.write("\r" + "Downloading %s ... %d%%" % (latest, percent))
	sys.stdout.flush()

def delete_chromium_dir(dir):
	full_dir = "%s/%s" % (latest_dir, dir)
	print 'Deleting ' + full_dir + ' ',
	if os.path.isdir(full_dir):
		shutil.rmtree(full_dir)
		print '[DONE]'
	else:
		print '[NOT FOUND]'

def delete_chromium_files(files):
	full_path = "%s/%s" % (latest_dir, files)
	print 'Deleting ' + full_path + ' ',
	for filename in glob.glob(full_path):
		print 'Deleting ' + filename + ' ',
		os.remove(filename)
		print '[DONE]'

chromium_url = "http://build.chromium.org/buildbot/official/"
chromium_root_dir = "/home/spot/chromium"

usock = urllib.urlopen(chromium_url)
parser = URLLister()
parser.feed(usock.read())
usock.close()

# sort the list of urls we got
parser.urls.sort()

# get the last item in the list
# this should always be the newest build
latest = parser.urls.pop()

chromium_version = re.sub('chromium-', '', latest)
chromium_version = re.sub('.tar.bz2', '', chromium_version)

print "Latest Chromium Version found at %s is %s" % (chromium_url, chromium_version)

latest_tarball_url = "%s%s" % (chromium_url, latest)
latest_dir = "%s/chromium-%s" % (chromium_root_dir, chromium_version)

# Let's make sure we haven't already downloaded it.
if os.path.isfile("./%s" % latest):
	print "%s already exists!" % latest
else:
	# Perhaps look at using python-progressbar at some point?
	urllib.urlretrieve(latest_tarball_url, latest, reporthook=dlProgress)
	urllib.urlcleanup()
	print ""

# Lets make sure we haven't unpacked it already
if os.path.isdir(latest_dir):
	print "%s already exists, perhaps %s has already been unpacked?" % (latest_dir, latest)
else:
	# Okay, now we need to open that puppy up.
	print "Unpacking %s into %s, please wait." % (latest, latest_dir)
	tar = tarfile.open(latest, "r:bz2")
	tar.extractall(path=chromium_root_dir)
	tar.close

junk_dirs = ['courgette', 'o3d', 
	     'third_party/WebKit/WebKitTools/Scripts/webkitpy/layout_tests', 
             'webkit/data/layout_tests', 'third_party/hunspell/dictionaries', 
             'chrome/test/data', 'native_client/tests', 
             'third_party/WebKit/LayoutTests', 'v8/include', 'v8/src', 
             'third_party/nss', 'third_party/nspr', 'third_party/icu', 
             'third_party/expat/files', 
             'third_party/ffmpeg/binaries', 
             'third_party/ffmpeg/source/patched-ffmpeg-mt/doc',
             'third_party/ffmpeg/source/patched-ffmpeg-mt/ffpresets',
             'third_party/ffmpeg/source/patched-ffmpeg-mt/mt-work',
             'third_party/ffmpeg/source/patched-ffmpeg-mt/tools',
             'third_party/ffmpeg/source/patched-ffmpeg-mt/tests',
             'third_party/zlib/contrib',
             'third_party/libevent/compat', 'third_party/libevent/linux',
             'third_party/libevent/mac', 'third_party/libevent/sample', 
             'third_party/libevent/test', 'third_party/libxml/build', 
             'third_party/libxml/include', 'third_party/libxml/linux',
             'third_party/libxml/mac', 'third_party/libxml/win32',
             'third_party/libxslt/build', 'third_party/libxslt/libexslt',
             'third_party/libxslt/libxslt', 'third_party/libxslt/linux',
             'third_party/libxslt/mac', 'third_party/libxslt/win32',
             'third_party/WebKit/WebCore/platform/image-decoders/zlib/']

junk_files = ['third_party/bzip2/*.c', 'third_party/bzip2/*.h', 'third_party/bzip2/LICENSE',
              'third_party/libjpeg/*.c', 'third_party/libjpeg/README*', 
              'third_party/libpng/*.c', 'third_party/libpng/*.h', 'third_party/libpng/README*', 'third_party/libpng/LICENSE',
              'third_party/zlib/*.c', 'third_party/zlib/*.h', 'third_party/zlib/README*',
              'third_party/libevent/*.c', 'third_party/libevent/*.h', 'third_party/libevent/*sh', 'third_party/libevent/config*'
              'third_party/libevent/*.3', 'third_party/libevent/README', 'third_party/libevent/ChangeLog', 
              'third_party/libevent/Makefile.*', 'third_party/libevent/aclocal.m4', 'third_party/libevent/*.py', 
              'third_party/libevent/missing', 'third_party/libevent/mkinstalldirs',
              'third_party/libxml/*.c', 'third_party/libxml/*.h', 'third_party/libxml/*.in',
              'third_party/libxml/*.m4', 'third_party/libxml/*.py', 'third_party/libxml/*.xml',
              'third_party/libxml/missing', 'third_party/libxml/mkinstalldirs', 'third_party/libxml/*.1',
              'third_party/libxml/AUTHORS', 'third_party/libxml/COPYING', 'third_party/libxml/ChangeLog',
              'third_party/libxml/Copyright', 'third_party/libxml/INSTALL', 'third_party/libxml/NEWS',
              'third_party/libxml/README', 'third_party/libxml/README.tests', 'third_party/libxml/TODO*',
              'third_party/libxml/config*', 'third_party/libxml/*.pl',
              'third_party/libxslt/AUTHORS', 'third_party/libxslt/COPYING', 'third_party/libxslt/ChangeLog',
              'third_party/libxslt/FEATURES', 'third_party/libxslt/INSTALL', 'third_party/libxslt/NEWS',
              'third_party/libxslt/README', 'third_party/libxslt/TODO', 'third_party/libxslt/*.h', 
              'third_party/libxslt/*.m4', 'third_party/libxslt/compile', 'third_party/libxslt/config*',
              'third_party/libxslt/depcomp', 'third_party/libxslt/*sh', 'third_party/libxslt/*.in',
              'third_party/libxslt/*.spec', 'third_party/libxslt/missing', 
              'third_party/ffmpeg/source/patched-ffmpeg-mt/*.c', 'third_party/ffmpeg/source/patched-ffmpeg-mt/*.h',
              'third_party/ffmpeg/source/patched-ffmpeg-mt/libavformat/*.c', 
              'third_party/ffmpeg/source/patched-ffmpeg-mt/libavcodec/*.c', 
              'third_party/ffmpeg/source/patched-ffmpeg-mt/libavutil/*.c',
              'third_party/ffmpeg/source/patched-ffmpeg-mt/libavfilter/*.c',
              'third_party/ffmpeg/source/patched-ffmpeg-mt/libavdevice/*.c',
              'third_party/ffmpeg/source/patched-ffmpeg-mt/libpostproc/*.c',
              'third_party/ffmpeg/source/patched-ffmpeg-mt/libswscale/*.c']

# Okay, now we clean out the junk.

# First, the dirs:
for dir in junk_dirs: 
	delete_chromium_dir(dir)

# Then, the files:
for file in junk_files:
	delete_chromium_files(file)

# There has got to be a better, more portable way to do this.
os.system("find %s -depth -name reference_build -type d -exec rm -rf {} \;" % latest_dir)

# I could not find good bindings for xz/lzma support, so we system call here too.

chromium_clean_xz_file = "chromium-" + chromium_version + "-clean.tar.lzma"

if os.path.isfile("%s/%s" % (chromium_root_dir, chromium_clean_xz_file)):
        print "%s already exists!" % chromium_clean_xz_file
else:
	print "Compressing cleaned tree, please wait..."
	os.chdir(chromium_root_dir)
	os.system("tar --exclude=\.svn -cf - chromium-%s | xz -9 -F lzma > %s" % (chromium_version, chromium_clean_xz_file))
	print "done!"
