%global momorel 2

# Update this with every matching v8 build
%global v8ver   2.3.5

# We need policy first.
%global selinux 0

# Useful for debugging
%global noisy 0

# Really, we want this on, but for testing...
%global sharedbuild 1

## Maybe, someday, I'll be able to flip these on. ##

# Chromium depends on forked sqlite features not foind in upstream.
%global sqlite 0

# Chromium depends on forked NSS features not found in upstream.
%global nss 0

Name:		chromium
# see src/chrome/VERSION
# Google's versioning is interesting. They never reset "BUILD", which is how we jumped
# from 3.0.201.0 to 4.0.202.0 as they moved to a new major branch
Version:	6.0.487.0
Release:	%{momorel}m%{?dist}
Summary:	A WebKit powered web browser
# Licensing Overview
# 
# ffmpeg headers are LGPLv2+
# libjingle is BSD

# TODO: Proper list of licenses
License:	BSD and LGPLv2+
Group:		Applications/Internet

# Just the code changes, none of the "makefile" changes
Patch0:		chromium-6.0.486.0-codechanges-system-minizip-nss-nspr.patch

# These are the conditionals that upstream has added:
# bzip2, jpeg, png, zlib, xml, xslt, libevent

# Hack support in for system v8
Patch2:		chromium-6.0.453.1-system-gyp-v8.patch

# We also remove minizip, which google left in because ubuntu doesn't have it. :P
Patch4:		chromium-20090807-gyp-system-minizip.patch

# Use system libicu
Patch7:		chromium-6.0.486.0-gyp-system-icu.patch

# Code changes to use system libicu
Patch8:		chromium-6.0.486.0-icu-code-changes.patch

# Revert this change to stop crashes
# http://src.chromium.org/viewvc/chrome/trunk/src/chrome/common/sqlite_utils.cc?r1=24321&r2=25633
Patch9:		chromium-20100218-no-sqlite-debug.patch

# webkit needs to call nss to pull in nspr headers
Patch10:	chromium-20100419-system-nss.patch

# Fix shared libs
Patch11:	chromium-6.0.476.0-sharedlibfixes.patch

# Fix ChromiumThreading issue in wtf shared lib
Patch12:	chromium-6.0.451.0-shared-chromiumthreading.patch

# Don't use the second copy of zlib
Patch13:	chromium-20100808-system-zlib.patch

# Don't embed incorrect RPATH into shared libs
Patch14:	chromium-20091209-norpath.patch

# Courgette not in source tree
Patch15:	chromium-20100218-no-courgette.patch

# Nacl needs fPIC (even on x86_32)
Patch16:	chromium-5.0.395.0-nacl-needs-fPIC.patch

# chrome_dll_main.c needs libnacl for NaClMain()
Patch17:	chromium-20100315-NaClMain.patch

# Use system libGLEW
# Patch18:	chromium-5.0.395.0-system-glew.patch

# Don't try to build non-existent test sources
Patch19:	chromium-no-test-sources.patch

# Fix the wrapper
Patch20:	chromium-fix-wrapper.patch

# Fix media probing
Patch22:	chromium-6.0.412.0-media-probe.patch

# Use system expat
Patch23:	chromium-6.0.425.0-system-expat.patch

# Fix ffmpeg wrapper compile
Patch24:	chromium-6.0.425.0-ffmpegfix.patch
Patch25:	chromium-6.0.425.0-ffmpeg-no-pkgconfig.patch

# Fix zlib gyp file to not build empty shell
Patch26:	chromium-20100408-no-empty-shell-zlib.patch

# Fix yuv_row_posix when compiled with -fPIC
Patch27:	chromium-20100413-fix-yuv_row_posix-shared.patch

# OLD: Use chromium-daily-tarball.sh to generate tarball from svn.
# New: Use chromium-latest.py to generate clean tarball from released build tarballs, found here:
# http://build.chromium.org/buildbot/official/
#Source0:	chromium-%{version}-clean.tar.lzma
Source0:	http://build.chromium.org/buildbot/official/chromium-%{version}.tar.bz2
NoSource: 0
# Custom build tools for chromium, hammer is a fancy front-end for scons
Source1:	http://src.chromium.org/svn/trunk/tools/depot_tools.tar.gz
Source2:	chromium-browser.sh
Source3:	chromium-browser.desktop
# We don't actually use this in the build, but it is included so you can make the tarball.
Source4:	chromium-daily-tarball.sh
Source5:	chromium-browser.xml
# Set default prefs
Source6:	master_preferences
# Also, only used if you want to reproduce the clean tarball.
Source7:	chromium-latest.py

BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires:	bzip2-devel, libevent-devel, libjpeg-devel, libpng-devel
BuildRequires:	libxslt-devel, nss-devel, nspr-devel, minizip-devel
BuildRequires:	gcc-c++, bison, flex, gtk2-devel, atk-devel
BuildRequires:	fontconfig-devel, GConf2-devel, dbus-devel, alsa-lib-devel
BuildRequires:	desktop-file-utils, gperf, libselinux-devel
BuildRequires:	nss-devel >= 3.12.3, expat-devel
BuildRequires:	dbus-glib-devel, libXScrnSaver-devel
BuildRequires:	cups-devel
#BuildRequires:	v8-devel

BuildRequires:  libicu-devel >= 4.2

# NaCl needs these
BuildRequires:  libstdc++-devel, openssl-devel

%if 0%{?sqlite}
BuildRequires:	sqlite-devel
%endif

# On x86_64, it also needs these:
# %ifarch x86_64
# BuildRequires:	glibc-devel(x86-32), libgcc(x86-32)
# %endif

%if 0%{?selinux}
BuildRequires:	libselinux-devel
%endif

ExclusiveArch:	%{ix86} arm x86_64

# GTK modules it expects to find for some reason.
Requires:	libcanberra

# We pick up an automatic requires on the library, but we need the version check
# because the nss shared library is unversioned.
# This is to prevent someone from hitting http://code.google.com/p/chromium/issues/detail?id=26448
Requires:	nss%{_isa} >= 3.12.3
Requires:	nss-mdns%{_isa}

# We want to make sure we have the chromium-libs
Requires:	chromium-libs = %{version}-%{release}

%description
Chromium is an open-source web browser, powered by WebKit.

%package libs
Summary:	Shared libraries for chromium
Group:		System Environment/Libraries
# We hardcode this because we don't get symbol deps with newer v8 versions
# This forces an upgrade
#Requires:	v8 >= %{v8ver}
Obsoletes:	v8 v8-devel

%description libs
This package contains the shared libraries that chromium depends on. Some of 
these libraries are unique to chromium, others are forked versions of system 
libraries.

%prep
echo "####### BUILD OPTIONS #######"
echo "Using system NSS: %{nss}"
echo "Using system sqlite3: %{sqlite}"
echo "Built-in SELinux support: %{selinux}"
echo "Verbose Build: %{noisy}"
%setup -q -n chromium-%{version} -a 1
cp %{SOURCE4} .

# Patch in code changes for system libs
%patch0 -p1 -b .system-code

# Hack in support for system v8 
#%patch2 -p1 -b .system-v8

# Fix the zlib.gyp file to use system minizip
%patch4 -p1 -b .system-minizip

# Use system libicu
%patch7 -p1 -b .system-icu

# Code changes to use system libicu
%patch8 -p1 -b .icu

# Revert sqlite debugging to stop crashes
%patch9 -p1 -b .no-sqlite-debugging

# Webkit needs to pull in nss to get to nspr headers
%patch10 -p1 -b .system-nss

# Fix missing symbols in shared libs
%patch11 -p1 -b .sharedlibsfixes

# Fix ChromiumThreading issue in wtf shared lib
%patch12 -p1 -b .chromiumthreading

# Don't use the second copy of zlib either
%patch13 -p1 -b .system-zlib

# Don't embed incorrect rpath into shared libs
%patch14 -p1 -b .norpath

# Courgette not in source tree
%patch15 -p1 -b .no-courgette

# Nacl needs fPIC, even on x86_32
%patch16 -p1 -b .fPIC

# chrome_dll_main.c needs libnacl for NaClMain()
%patch17 -p1 -b .NaClMain

# Use system libGLEW
# They've forked this beyond recognition.
# %patch18 -p1 -b .GLEW

# Don't try to build non-existent test sources
%patch19 -p1 -b .notests

# Fix the wrapper
%patch20 -p1 -b .fix

# Fix media probing
%patch22 -p1 -b .media-probe

# Use system expat
%patch23 -p1 -b .system-expat

# Fix ffmpeg wrapper
%patch24 -p1 -b .fix-ffmpeg
%patch25 -p1 -b .no-pkgconfig

# Don't build stupid empty shell zlib
%patch26 -p1 -b .empty-shell

%patch27 -p1 -b .fix-yrp

# Scrape out incorrect optflags and hack in the correct ones
PARSED_OPT_FLAGS=`echo \'$RPM_OPT_FLAGS -DUSE_SYSTEM_LIBEVENT -DUSE_MMX -fPIC -fno-strict-aliasing \' | sed "s/ /',/g" | sed "s/',/', '/g"`
for i in build/common.gypi; do
        sed -i "s|'-march=pentium4',||g" $i
        sed -i "s|'-mfpmath=sse',||g" $i
        sed -i "s|'-O<(debug_optimize)',||g" $i
        sed -i "s|'-m32',||g" $i
        sed -i "s|'-fno-exceptions',|$PARSED_OPT_FLAGS|g" $i
done


# Also, set the sandbox paths correctly.
# We set use_system_ffmpeg so chromium doesn't try to build ffmpeg source that we strip out

./build/gyp_chromium -f make build/all.gyp \
			       --depth . \
                               -Dlinux_sandbox_path=%{_libdir}/chromium-browser/chrome-sandbox \
			       -Dlinux_sandbox_chrome_path=%{_libdir}/chromium-browser/chromium-browser \
%ifarch x86_64
                               -Dtarget_arch=x64 \
%endif
		               -Duse_system_libpng=1 \
		 	       -Duse_system_bzip2=1 \
			       -Duse_system_libjpeg=1 \
			       -Duse_system_zlib=1 \
                               -Duse_system_libxslt=1 \
                               -Duse_system_libxml=1 \
		               -Duse_system_ffmpeg=1 \
		       	       -Dbuild_ffmpegsumo=1 \
%if 0%{?nss}
                               -Duse_system_ssl=1 \
%endif
                               -Duse_system_libevent=1 \
%if 0%{?selinux}
                               -Dselinux=1 \
%endif
%if 0%{?sqlite}
                               -Duse_system_sqlite=1 \
%endif
                               -Dlibrary=shared_library \
                               -Drelease_extra_cflags=-fPIC \
                               -Djavascript_engine=v8



%build
%if 0%{?selinux}
%if 0%{?noisy}
make -r -j%{_numjobs} chrome BUILDTYPE=Release V=1
%else
make -r -j%{_numjobs} chrome BUILDTYPE=Release
%endif
%else
%if 0%{?noisy}
make -r -j%{_numjobs} chrome chrome_sandbox BUILDTYPE=Release V=1
%else
make -r -j%{_numjobs} chrome chrome_sandbox BUILDTYPE=Release
%endif
%endif

# If we're building sandbox without SELINUX, add "chrome_sandbox" here.
# %if 0%{?selinux}
# %if 0%{?noisy}
# ../../depot_tools/hammer --mode=Release --verbose chrome
# %else
# ../../depot_tools/hammer --mode=Release chrome
# %endif
# %else
# %if 0%{?noisy}
# ../../depot_tools/hammer --mode=Release --verbose chrome chrome_sandbox
# %else
# ../../depot_tools/hammer --mode=Release chrome chrome_sandbox
# %endif
# %endif

%install
rm -rf %{buildroot}
mkdir -p %{buildroot}%{_bindir}
cp -a %{SOURCE2} %{buildroot}%{_bindir}/chromium-browser
# x86_64 capable systems need this
sed -i "s|/usr/lib/chromium|%{_libdir}/chromium|g" %{buildroot}%{_bindir}/chromium-browser
mkdir -p %{buildroot}%{_libdir}/chromium-browser/
mkdir -p %{buildroot}%{_mandir}/man1/
pushd out/Release
cp -a chrome.pak locales resources resources.pak %{buildroot}%{_libdir}/chromium-browser/
cp -a chrome %{buildroot}%{_libdir}/chromium-browser/chromium-browser
cp -a lib.target/lib*.so %{buildroot}%{_libdir}/chromium-browser/
cp -a lib.host/lib*.so %{buildroot}%{_libdir}/chromium-browser/
# If we're building without SELINUX support, uncomment this line.
%if 0%{?selinux}
# Do nothing. Sandboxing is in the selinux policy and core binary.
%else
cp -a chrome_sandbox %{buildroot}%{_libdir}/chromium-browser/chrome-sandbox
%endif
cp -a chrome.1 %{buildroot}%{_mandir}/man1/chrome.1
cp -a chrome.1 %{buildroot}%{_mandir}/man1/chromium-browser.1
mkdir -p %{buildroot}%{_libdir}/chromium-browser/plugins/
popd

mkdir -p %{buildroot}%{_datadir}/pixmaps/
cp -a chrome/app/theme/chromium/product_logo_48.png %{buildroot}%{_datadir}/pixmaps/chromium-browser.png

mkdir -p %{buildroot}%{_datadir}/applications/
desktop-file-install --vendor= --dir %{buildroot}%{_datadir}/applications %{SOURCE3}

mkdir -p %{buildroot}%{_datadir}/gnome-control-center/default-apps/
cp -a %{SOURCE5} %{buildroot}%{_datadir}/gnome-control-center/default-apps/

# Install the master_preferences file
mkdir -p %{buildroot}%{_sysconfdir}
install -m 0644 %{SOURCE6} %{buildroot}%{_sysconfdir}/%{name}

# This enables HTML5 video if you have ffmpeg installed, you naughty naughty user.
pushd %{buildroot}%{_libdir}/chromium-browser
touch %{buildroot}%{_libdir}/libavcodec.so.52
ln -s %{_libdir}/libavcodec.so.52 libavcodec.so.52
touch %{buildroot}%{_libdir}/libavformat.so.52
ln -s %{_libdir}/libavformat.so.52 libavformat.so.52
touch %{buildroot}%{_libdir}/libavutil.so.50
ln -s %{_libdir}/libavutil.so.50 libavutil.so.50
popd

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc chromium-daily-tarball.sh
%{_bindir}/chromium-browser
%{_libdir}/chromium-browser/chrome.pak
%{_libdir}/chromium-browser/chromium-browser
# Uncomment this line if building without SELINUX
%if 0%{?selinux}
# Do nothing. Sandboxing is in the selinux policy and core binary.
%else
# These unique permissions are intentional and necessary for the sandboxing
%attr(4555, root, root) %{_libdir}/chromium-browser/chrome-sandbox
%endif
%{_libdir}/chromium-browser/locales/
%{_libdir}/chromium-browser/plugins/
%{_libdir}/chromium-browser/resources/
%{_libdir}/chromium-browser/resources.pak
# %%{_libdir}/chromium-browser/themes/
%{_mandir}/man1/chrom*
%{_datadir}/pixmaps/chromium-browser.png
%{_datadir}/applications/*.desktop
%{_datadir}/gnome-control-center/default-apps/chromium-browser.xml
%{_sysconfdir}/%{name}

%files libs
%defattr(-,root,root,-)
%dir %{_libdir}/chromium-browser/
# These are dummy symlinks. You'll have to install ffmpeg-libs to get them for real.
%{_libdir}/chromium-browser/libavcodec.so.52
%{_libdir}/chromium-browser/libavutil.so.50
%{_libdir}/chromium-browser/libavformat.so.52
# These are real.
%{_libdir}/chromium-browser/liballocator.so
%{_libdir}/chromium-browser/libapp_base.so
%{_libdir}/chromium-browser/libappcache.so
%{_libdir}/chromium-browser/libbase.so
%{_libdir}/chromium-browser/libbase_i18n.so
%{_libdir}/chromium-browser/libbrowser.so
%{_libdir}/chromium-browser/libcacheinvalidation.so
%{_libdir}/chromium-browser/libchrome_gpu.so
%{_libdir}/chromium-browser/libchromoting_base.so
%{_libdir}/chromium-browser/libchromoting_client.so
%{_libdir}/chromium-browser/libchromoting_host.so
%{_libdir}/chromium-browser/libchromoting_jingle_glue.so
%{_libdir}/chromium-browser/libchromotocol_proto_lib.so
%{_libdir}/chromium-browser/libcld.so
%{_libdir}/chromium-browser/libcommon.so
%{_libdir}/chromium-browser/libcommon_constants.so
%{_libdir}/chromium-browser/libcommon_net.so
%{_libdir}/chromium-browser/libdatabase.so
%{_libdir}/chromium-browser/libdebugger.so
%{_libdir}/chromium-browser/libdefault_plugin.so
%{_libdir}/chromium-browser/libdynamic_annotations.so
# Note: This is a dummy lib. There isn't any ffmpeg code in here.
%{_libdir}/chromium-browser/libffmpeg.so
%{_libdir}/chromium-browser/libgfx.so
%{_libdir}/chromium-browser/libglue.so
%{_libdir}/chromium-browser/libgoogleurl.so
%{_libdir}/chromium-browser/libgtest.so
%{_libdir}/chromium-browser/libharfbuzz.so
%{_libdir}/chromium-browser/libharfbuzz_interface.so
%{_libdir}/chromium-browser/libhttp_listen_socket.so
%{_libdir}/chromium-browser/libhunspell.so
%{_libdir}/chromium-browser/libipc.so
%{_libdir}/chromium-browser/libil.so
%{_libdir}/chromium-browser/libinstaller_util.so
%{_libdir}/chromium-browser/libjingle.so
%{_libdir}/chromium-browser/libjingle_p2p.so
%{_libdir}/chromium-browser/libchrome_version_info.so
%{_libdir}/chromium-browser/libmedia.so
%{_libdir}/chromium-browser/libmodp_b64.so
# This isn't a shared lib anymore. A shame.
# %{_libdir}/chromium-browser/libnacl.so
%{_libdir}/chromium-browser/libnet.so
%{_libdir}/chromium-browser/libnet_base.so
%{_libdir}/chromium-browser/libnotifier.so
%{_libdir}/chromium-browser/libomx_wrapper.so
%{_libdir}/chromium-browser/libots.so
%{_libdir}/chromium-browser/libpcre.so
%{_libdir}/chromium-browser/libplugin.so
%{_libdir}/chromium-browser/libprinting.so
%{_libdir}/chromium-browser/libprofile_import.so
%{_libdir}/chromium-browser/libprotobuf.so
%{_libdir}/chromium-browser/libprotobuf_lite.so
%{_libdir}/chromium-browser/librenderer.so
%{_libdir}/chromium-browser/libsandbox.so
%{_libdir}/chromium-browser/libsdch.so
%{_libdir}/chromium-browser/libservice.so
%{_libdir}/chromium-browser/libskia.so
%{_libdir}/chromium-browser/libskia_opts.so
%if 0%{?sqlite}
# Do nothing. We're using system-y goodness.
%else
%{_libdir}/chromium-browser/libsqlite3.so
%endif
%if 0%{?nss}
# Do nothing. We're using system-y goodness.
%else
%{_libdir}/chromium-browser/libssl.so
%endif
%{_libdir}/chromium-browser/libsymbolize.so
%{_libdir}/chromium-browser/libsync.so
%{_libdir}/chromium-browser/libsyncapi.so
%{_libdir}/chromium-browser/libsync_notifier.so
%{_libdir}/chromium-browser/libutility.so
%{_libdir}/chromium-browser/libv8_base.so
%{_libdir}/chromium-browser/libv8_nosnapshot.so
%{_libdir}/chromium-browser/libv8_snapshot.so
%{_libdir}/chromium-browser/libwebcore.so
%{_libdir}/chromium-browser/libwebcore_bindings.so
%{_libdir}/chromium-browser/libworker.so
%{_libdir}/chromium-browser/libwtf.so
%{_libdir}/chromium-browser/libxdg_mime.so
%exclude %{_libdir}/libavcodec.so.52
%exclude %{_libdir}/libavutil.so.50
%exclude %{_libdir}/libavformat.so.52

%changelog
* Tue Aug 31 2010 Yohsuke Ooi <meke@momonga-linux.org>
- (6.0.487.0-2m)
- full rebuild for mo7 release

* Mon Aug  9 2010 Yohsuke Ooi <meke@momonga-linux.org> 
- (6.0.487.0-1m)
- update 6.0.487
- Obsoletes v8, v8-devel

* Tue Jun  1 2010 Ichiro Nakai <ichiro@n.email.ne.jp>
- (6.0.417.0-2m)
- fix build on i686, %%global sharedbuild 1

* Thu Jun  1 2010 Masanobu Sato  <satoshiga@momonga-linux.org>
- (6.0.417.0-1m)
- update and sync to Fedora

* Fri May 14 2010 Masanobu Sato  <satoshiga@momonga-linux.org>
- (6.0.399.0-1m)
- update and sync to Fedora

* Fri May 14 2010 Ichiro Nakai <ichiro@n.email.ne.jp>
- (4.0.220.0-5m)
- rebuild against icu-4.2.1

* Sat Apr 10 2010 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (4.0.220.0-4m)
- rebuild against libjpeg-8a

* Sat Nov 14 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (4.0.220.0-3m)
- rebuild against gcc-4.4 and glibc-2.11

* Wed Oct 14 2009 Masanobu Sato <satoshiga@momonga-linux.org>
- (4.0.220.0-2m)
- revised 64bit-plugin-path.patch

* Wed Oct  7 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (4.0.220.0-1m)
- sync

* Wed Sep 23 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (4.0.212.0-1m)
- change release

* Wed Sep 23 2009 Nishio Futoshi <futoshi@momonga-linux.org>
- (4.0.212.0-0.1.20090916svn26424.1m)
- initial build on Momonga
-- http://spot.fedorapeople.org/chromium/F12/

* Wed Sep 16 2009 Tom "spot" Callaway <tcallawa@redhat.com> 4.0.212.0-0.1.20090916svn26424
- 20090916svn26424
- revert http://src.chromium.org/viewvc/chrome/trunk/src/chrome/common/sqlite_utils.cc?r1=24321&r2=25633
  to stop crashes when typing in url bar

* Thu Sep 10 2009 Tom "spot" Callaway <tcallawa@redhat.com> 4.0.208.0-0.1.20090910svn25958
- 20090910svn25958

* Wed Sep 9 2009 Tom "spot" Callaway <tcallawa@redhat.com> 4.0.208.0-0.1.20090909svn25824
- 20090909svn25824
- drop hardcoded Requires on bug-buddy (fixes issue where it is being obsoleted by abrt in rawhide)
- disable webkit deopt, flash bug is fixed now
- use system libicu

* Thu Aug 27 2009 Tom "spot" Callaway <tcallawa@redhat.com> 4.0.204.0-0.1.20090827svn24640
- 20090827svn24640

* Tue Aug 25 2009 Tom "spot" Callaway <tcallawa@redhat.com> 4.0.203.0-0.1.20090824svn24148
- 20090824svn24148
- find proper plugin dir on x86_64
- pass --enable-user-scripts (instead of old --enable-greasemonkey)

* Tue Aug 18 2009 Tom "spot" Callaway <tcallawa@redhat.com> 4.0.202.0-0.1.20090818svn23628
- 20090818svn23628

* Fri Aug 14 2009 Tom "spot" Callaway <tcallawa@redhat.com> 4.0.202.0-0.1.20090814svn23460
- 20090814svn23460

* Wed Aug 12 2009 Tom "spot" Callaway <tcallawa@redhat.com> 4.0.202.0-0.1.20090812svn23201
- Bump to 4.0.202 (we're not tracking 3.0, no one can tell me exactly how to manage that)

* Mon Aug 10 2009 Tom "spot" Callaway <tcallawa@redhat.com> 3.0.198.0-0.1.20090810svn22925
- 20090810svn22925

* Fri Aug  7 2009 Tom "spot" Callaway <tcallawa@redhat.com> 3.0.198.0-0.1.20090807svn22807
- 20090807svn22807

* Wed Aug  5 2009 Tom "spot" Callaway <tcallawa@redhat.com> 3.0.198.0-0.1.20090805svn22496
- 20090805svn22496

* Mon Aug  3 2009 Tom "spot" Callaway <tcallawa@redhat.com> 3.0.197.0-0.1.20090803svn22262
- 20090803svn22262

* Fri Jul 31 2009 Tom "spot" Callaway <tcallawa@redhat.com> 3.0.197.0-0.1.20090731svn22188
- 20090731svn22188

* Thu Jul 30 2009 Tom "spot" Callaway <tcallawa@redhat.com> 3.0.197.0-0.1.20090730svn22105
- 20090730svn22105

* Mon Jul 27 2009 Tom "spot" Callaway <tcallawa@redhat.com> 3.0.196.0-0.1.20090727svn21648
- 20090727svn21648

* Fri Jul 24 2009 Tom "spot" Callaway <tcallawa@redhat.com> 3.0.196.0-0.1.20090724svn21567
- 20090724svn21567
- drop ffmpeg binaries (only code remaining is headers, doesn't infringe patents)
- package up manpage

* Mon Jul 20 2009 Tom "spot" Callaway <tcallawa@redhat.com> 3.0.195.0-0.1.20090720svn21073
- 20090720svn21073

* Thu Jul 16 2009 Tom "spot" Callaway <tcallawa@redhat.com> 3.0.195.0-0.1.20090716svn20889
- 20090716svn20889

* Wed Jul 15 2009 Tom "spot" Callaway <tcallawa@redhat.com> 3.0.195.0-0.1.20090715svn20726
- 20090715svn20726

* Mon Jul 13 2009 Tom "spot" Callaway <tcallawa@redhat.com> 3.0.194.0-0.1.20090713svn20473
- 20090713svn20473

* Sat Jul 11 2009 Tom "spot" Callaway <tcallawa@redhat.com> 3.0.194.0-0.1.20090711svn20464
- 20090711svn20464
- fix sandboxing up to match code changes (no longer need to be read-only, doesn't need /var/run/chrome-sandbox)

* Wed Jul  8 2009 Tom "spot" Callaway <tcallawa@redhat.com> 3.0.193.0-0.1.20090708svn20141
- 20090708svn20141
- support LinuxZygote sandboxing

* Sat Jul  4 2009 Tom "spot" Callaway <tcallawa@redhat.com> 3.0.192.0-0.1.20090704svn19929
- 20090704svn19929
- hack in correct optflags

* Sun Jun 28 2009 Tom "spot" Callaway <tcallawa@redhat.com> 
- 20090628svn19474

* Fri Jun 26 2009 Tom "spot" Callaway <tcallawa@redhat.com>
- 20090626svn19370

* Thu Jun 25 2009 Tom "spot" Callaway <tcallawa@redhat.com> 
- 3.0.191.0 20090625svn19237

* Thu Jun 18 2009 Tom "spot" Callaway <tcallawa@redhat.com>
- 3.0.190.0 20090618svn18706

* Mon Jun 8 2009 Tom "spot" Callaway <tcallawa@redhat.com>
- 20090608svn17870

* Sat Jun 6 2009 Tom "spot" Callaway <tcallawa@redhat.com>
- 20090606svn17834
